@@ -492,14 +492,16 @@ def main(args=None):
 
         try:
             model = KMC_Model(print_rates=False)
-        except:
-            print("Warning: could not import kmc_model!"
-                  " Please make sure you are in the right directory")
+        except Exception as theError:
+            print("Warning: could not import kmc_model! The error was:", theError,
+                  "\n Please make sure you are in the right directory")        
+
+
         sh(banner='Note: model = KMC_Model(print_rates=False){catmap_message}'.format(**locals()))
         try:
             model.deallocate()
         except:
-            print("Warning: could not deallocate model. Was is allocated?")
+            print("Warning: could not deallocate model. Was it allocated?")
 
     elif args[0] == 'version':
         from kmcos import VERSION
